@@ -102,6 +102,7 @@ void open_dir(GtkTreeView * treeview, GtkTreeIter * iter, GtkTreePath * treepath
     static gchar **window_title=NULL;
     static gboolean red_light=FALSE;
     GtkTreeSortable *sortable=GTK_TREE_SORTABLE(treemodel);
+
     
 #ifdef DEBUG
 	printf("DBG: open_dir ...\n");
@@ -372,6 +373,7 @@ void close_dir(GtkTreeView * treeview, GtkTreeIter * iter, GtkTreePath * path, g
     static gchar **window_title=NULL;
     GtkTreeModel *treemodel = gtk_tree_view_get_model(treeview);
 
+
     mousedown=FALSE; /* gtk bug workaround:click on expander passes button_press but not button_release */
     if (clickpath){
         clear_path_from_selection_list(treeview,clickpath);
@@ -631,6 +633,7 @@ gboolean button_releaseF(GtkWidget * widget, GdkEventButton * event, gpointer da
     return FALSE;
 }
 
+static gboolean unsel(GtkTreeModel *,GtkTreePath *, GtkTreeIter *, gpointer);
 
 
 G_MODULE_EXPORT
@@ -665,7 +668,6 @@ gboolean treeclick(GtkWidget * widget, GdkEventButton * event, gpointer data)
     skip_second_release = FALSE;
 
     for (tree_id=0; tree_id<TREECOUNT; tree_id++) {      
-      static gboolean unsel(GtkTreeModel *,GtkTreePath *, GtkTreeIter *, gpointer);
       /*printf("DBG: treeview is  0x%x==0x%x\n",tree_details->treestuff[tree_id].treeview,treeview);*/
       if (treeview != tree_details->treestuff[tree_id].treeview){
         /* unselect all in auxiliary treeview */
@@ -997,7 +999,9 @@ void on_remove_from_results_activate(GtkMenuItem * menuitem, gpointer user_data)
     }
     gtk_tree_selection_set_mode(selection, GTK_SELECTION_MULTIPLE);
     get_find_root(treeview, &parent, &en);
-    insert_dummy_row(treemodel, &parent,NULL,en,"xfce/info",_("Nothing searched"));
+    if (!gtk_tree_model_iter_has_child(treemodel,&parent)) {
+	insert_dummy_row(treemodel, &parent,NULL,en,"xfce/info",_("Nothing searched"));
+    }
 }
 
 
