@@ -617,7 +617,9 @@ set_auto_command(			int j,
 		 gtk_label_set_text((GtkLabel *)label,my_utf_string(alt_label));
 	      } else {
 		  gchar *new_label;
-		  gchar *fname=g_path_get_basename(path);
+		  gchar *ffname=g_path_get_basename(path);
+		  gchar *fname=g_strdup(my_utf_string(ffname));
+		  g_free(ffname);
 		  if (queued && *queued && output_arg) new_label=g_strdup(app);
 		  else new_label=g_strdup(MIME_mk_command_line(app,fname,FALSE,FALSE));
 		  gtk_label_set_text((GtkLabel *)label,my_utf_string(new_label));
@@ -710,12 +712,14 @@ alt_menu_label(			const gchar *label, const gchar *path,const gchar *extension)
     gchar *alt_label=NULL;
     if (label) 
     { 
-	gchar *fname=g_path_get_basename(path);
+	gchar *fffname=g_path_get_basename(path);
+	gchar *fname=g_strdup(my_utf_string(path));
 	gchar *ffname=g_strconcat(fname,extension,NULL);
+	g_free(fffname);   
 	if (strstr(label,"%s")) {
-	    alt_label=g_strdup_printf(label,ffname);
+	    alt_label=g_strdup_printf(my_utf_string(label),ffname);
 	} else {
-	    alt_label=g_strdup_printf("%s %s",label,ffname);
+	    alt_label=g_strdup_printf("%s %s",my_utf_string(label),ffname);
 	}
 	g_free(fname);
 	g_free(ffname);   
