@@ -106,6 +106,7 @@ static int childFD;
 static xfdir_t fstat_xfdir;
 static pid_t Gpid;
 static GtkTreeView *fstab_treeview;
+static  GtkTreeRowReference *fstab_reference=NULL;
 
 /* exported prototypes */
 int is_mounted(const gchar *mnt_point);
@@ -182,16 +183,47 @@ static void fork_finished_function(pid_t pid)
     cursor_reset();
     /* another wait just in case the one in tubo misses 
      * (shouldn't happen, but it does)*/
-    
+    TRACE("fork_finished_function");
     waitpid(pid, &status, WNOHANG);
     en= get_selected_entry(&iter);
+    if (!en) {
+	TRACE("fork_finished_function all done");
+	if (fstab_reference) {
+	    gtk_tree_row_reference_free(fstab_reference);
+	    fstab_reference=NULL;
+	}
+	return;
+    }
     status=is_mounted((const gchar *)en->path);
     if (status < 0) TOGGLE_MOUNTED(en->type);
     else {
 	    if (status) SET_MOUNTED(en->type);
 	    else UNSET_MOUNTED(en->type);
     }
-    if (IS_MOUNTED(en->type))
+    if (fstab_treeview && fstab_reference && gtk_tree_row_reference_valid(fstab_reference)) {
+    	GtkTreeModel *treemodel = gtk_tree_view_get_model(fstab_treeview);
+      	GtkTreePath *treepath = gtk_tree_row_reference_get_path(fstab_reference);
+	if (treepath && gtk_tree_model_get_iter (treemodel,&iter,treepath)){
+	    if (IS_MOUNTED(en->type)){
+		int i;
+		for (i=0; i<TREECOUNT; i++){
+		    gtk_tree_selection_unselect_all(tree_details->treestuff[i].selection);
+		}
+		gtk_tree_selection_select_iter(gtk_tree_view_get_selection(fstab_treeview),&iter);
+		on_refresh((GtkButton *)(tree_details->window),NULL);
+	    }
+	    else  {
+		gtk_tree_view_collapse_row(fstab_treeview, treepath);
+		prune_row(treemodel, &iter, NULL,en);
+		insert_dummy_row(treemodel, &iter, NULL,en,NULL,NULL);
+		update_icon(treemodel,&iter);
+	    }
+	    gtk_tree_path_free(treepath);
+	}
+	gtk_tree_row_reference_free(fstab_reference);
+	fstab_reference=NULL;
+    }
+    /*if (IS_MOUNTED(en->type))
 	on_refresh((GtkButton *)(tree_details->window),NULL);
     else {
     	GtkTreePath *treepath;
@@ -202,7 +234,7 @@ static void fork_finished_function(pid_t pid)
 	insert_dummy_row(treemodel, &iter, NULL,en,NULL,NULL);
     	gtk_tree_path_free(treepath);
 	update_icon(treemodel,&iter);
-    }
+    }*/
     
 #ifdef DEBUG  
     printf("DBG:fstab over by fork_finished_function\n");
@@ -301,6 +333,15 @@ fstab_mount (GtkTreeView *treeview, const gchar *mnt_point, gboolean umnt,tree_e
     static gchar *smb_browse=NULL;
     /*GtkTreeModel *treemodel = gtk_tree_view_get_model(treeview);*/
 
+    if (tree_details->window){
+	GtkTreePath *tpath;
+	GtkTreeIter iter;
+	get_selected_entry(&iter);
+	tpath = gtk_tree_model_get_path(tree_details->treestuff[get_active_tree_id()].treemodel, &iter);
+	fstab_reference = gtk_tree_row_reference_new(tree_details->treestuff[get_active_tree_id()].treemodel, tpath);
+	gtk_tree_path_free(tpath);
+    }
+
     g_free(smb_browse);
     smb_browse=NULL;
     /* this will set the is_smb variable: */
@@ -714,7 +755,6 @@ open_fstab (GtkTreeView *treeview, GtkTreeIter *iter, GtkTreePath *treepath,
 		else if (strcmp(MNTTYPE_CACHEFS, vbuf.vfs_fstype) == 0)
 			SET_PROC_TYPE(fstat_xfdir.gl[i].en->subtype);
 
-		i++;
 		/*
 		 * Check if filesystem is already mounted
 		 *  
@@ -724,9 +764,12 @@ open_fstab (GtkTreeView *treeview, GtkTreeIter *iter, GtkTreePath *treepath,
 			if (getmntent(mnttab_fp, &mbuf) != 0)
 				break;
 
-			if (strcmp(mbuf.mnt_mountp, vbuf.vfs_mountp) == 0) 
+			if (strcmp(mbuf.mnt_mountp, vbuf.vfs_mountp) == 0){ 
 		    		TOGGLE_MOUNTED(fstat_xfdir.gl[i].en->type);
+				break;
+			}
 		}
+		i++;
 	}
 
         (void)fclose(mnttab_fp);
