@@ -1,4 +1,4 @@
-/* (c) 2001-2003 Edscott Wilson Garcia GNU/GPL
+/* (c) 2001-2004 Edscott Wilson Garcia GNU/GPL
  */
 
 /*  functions to use tubo.c for listing contents of SMB shares 
@@ -21,6 +21,7 @@
 #ifdef HAVE_CONFIG_H
 #  include <config.h>
 #endif
+#ifdef USE_SMB_BRANCH
 #include <unistd.h>
 #include <stdarg.h>
 #include <signal.h>
@@ -39,16 +40,18 @@
 #include "constants.h"
 #include "types.h"
 
-#include "add_node_contents.h"
-#include "dummies.h"
+#include "basic_row.h"
+
+#include "smb_list.h"
+
 #include "entry.h"
-#include "gdir.h"
 #include "icons.h"
 #include "smblookup.h"
 #include "smb_open.h"
 #include "smb_misc.h"
 #include "misc.h"
 #include "tubo.h"
+#include "password_dialog.h"
 
 int query_result;
 extern unsigned net_root_type;
@@ -59,10 +62,11 @@ extern void *smb_object;
 
 static GList *listing=NULL;
 static int input_over;
+/* These variables *must* be thread safe (hence, use of _POSIX_PATH_MAX): */
 static  char smb_server[_POSIX_PATH_MAX];
 static  char smb_share[_POSIX_PATH_MAX];
 static  char smb_dir[_POSIX_PATH_MAX];
-static gdir_t smb_gdir;
+static xfdir_t smb_xfdir;
 static int smb_count;
 static gboolean samba_server;
 static gboolean showing_hidden;
@@ -97,11 +101,11 @@ int SMBListStdout (int n, void *data) {
   {
     char *l=g_strdup(line);
     ascii_readable(l);
-    print_diagnostics (smb_treeview,NULL,l,NULL);
+    print_diagnostics (NULL,l,NULL);
     g_free(l);
   }
 #else
-    print_diagnostics (smb_treeview,NULL,line,NULL);
+    print_diagnostics (NULL,line,NULL);
 #endif
   
     
@@ -112,8 +116,7 @@ int SMBListStdout (int n, void *data) {
   }
   for (i=0;smb_errors[i]!=NULL;i++){
       if (strstr (line, smb_errors[i]))  {
-	  print_diagnostics(smb_treeview,"xf_ERROR_ICON",
-			strerror(EPERM),NULL);
+	  print_diagnostics("xfce/error", strerror(EPERM),NULL);
       }	
   }
   if (strstr (line, "Connection") && strstr (line, "failed"))  {
@@ -255,7 +258,6 @@ int SMBListStdout (int n, void *data) {
   en->st->st_size=atoi(textos[SHARE_SIZE_COLUMN]);
 
   en->st->st_mtime=mktime(&t);
-  en->st->st_ctime=mktime(&t);
   en->st->st_gid = (gid_t)-1;
   en->st->st_uid = (uid_t)-1;
   en->st->st_mode=unix_mode;
@@ -273,17 +275,17 @@ static void SMBListForkOver (pid_t pid){
   switch (query_result)
   {
   case CHALLENGED:
-    print_status (smb_treeview,"xf_WARNING_ICON",
+    print_status ("xfce/warning",
 		    _("Query password has been requested"),
 		    NULL);
     break;
   case FAILED:
-    print_status (smb_treeview,"xf_ERROR_ICON",
+    print_status ("xfce/error",
 		    _("SMB query failed"),
 		    NULL);
   default:
 
-    print_status (smb_treeview,"xf_INFO_ICON",
+    print_status ("xfce/info",
 		    _("Retrieve done"),
 		    NULL);
     break;
@@ -297,33 +299,35 @@ printout_listing(gpointer data,gpointer user_data){
   char *pass=(char *)user_data;
   tree_entry_t *en=(tree_entry_t *)data;
   
-  if (!strrchr(en->path,'/')) g_assert_not_reached();
-  smb_gdir.gl[smb_count].pathv=g_strdup(strrchr(en->path,'/')+1);
-  if (!samba_server) ascii_readable(smb_gdir.gl[smb_count].pathv);
+  if (!strrchr(en->path,'/')) assert_not_reached();
+  smb_xfdir.gl[smb_count].pathv=g_strdup(strrchr(en->path,'/')+1);
+  if (!samba_server) ascii_readable(smb_xfdir.gl[smb_count].pathv);
   en->tag=g_strdup(pass);
-  smb_gdir.gl[smb_count].en=en;
+  smb_xfdir.gl[smb_count].en=en;
   smb_count++;
 }
 
 void add_smb_stuff(GtkTreeView *treeview,GtkTreeIter *iter,char *pass){
-  tree_details_t *tree_details = get_tree_details(treeview);
 	
+  GtkTreeModel *treemodel = gtk_tree_view_get_model(treeview);
   if (query_result==SUCCESS && listing){
-        smb_gdir.pathc = g_list_length(listing);
-        smb_gdir.gl = (dir_t *) malloc(smb_gdir.pathc * sizeof(dir_t));
+        smb_xfdir.pathc = g_list_length(listing);
+        smb_xfdir.gl = (dir_t *) malloc(smb_xfdir.pathc * sizeof(dir_t));
 	smb_count=0;
 	g_list_foreach(listing,printout_listing,(gpointer)pass);
-	add_node_contents(treeview, iter, &smb_gdir);
-        hide_stop(tree_details->window);
-	gdirfree(&smb_gdir);
+	add_contents_row(treemodel, iter, &smb_xfdir);
+	erase_dummy_row(treemodel, iter,NULL);
+        hide_stop();
+	xfdirfree(&smb_xfdir);
   } else if (query_result==SUCCESS && !listing){
     	tree_entry_t *en;
-    	GtkTreeModel *treemodel = gtk_tree_view_get_model(treeview);
     	gtk_tree_model_get(GTK_TREE_MODEL(treemodel), iter, ENTRY_COLUMN, &en, -1);
 	SET_EXPANDED(en->type);
-	set_icon(treeview, iter);
-	reset_dummy(treeview,iter,1);
-  } else reset_dummy(smb_treeview,iter,1);
+	set_icon(treemodel, iter);
+	reset_dummy_row(treemodel, iter,NULL,en,NULL,NULL);
+  } else {
+	reset_dummy_row(treemodel, iter,NULL,NULL,NULL,NULL);
+  }
 }
 
 void init_smb_list(GtkTreeView *treeview,char *path,gboolean show_hidden){
@@ -362,6 +366,7 @@ SMBList (GtkTreeView *treeview,char *path,GtkTreeIter *iter,
   char NMBcommand[_POSIX_PATH_MAX];
   char NMBshare[_POSIX_PATH_MAX];
   int i;
+  GtkTreeModel *treemodel = gtk_tree_view_get_model(treeview);
   if (!path || !strchr(path,'/')) return FALSE;
   init_smb_list(treeview,path,show_hidden);
   
@@ -392,8 +397,8 @@ SMBList (GtkTreeView *treeview,char *path,GtkTreeIter *iter,
   argument[i++]=NMBcommand;
   argument[i++]=0;
   
-  print_status (treeview,"xf_INFO_ICON",_("Retrieving..."),NULL);
-  print_diagnostics (treeview,NULL,"XFSAMBA> ",
+  print_status (NULL,_("Retrieving..."),NULL);
+  print_diagnostics ("nonverbose","XFSAMBA> ",
 		  "smbclient"," ",NMBshare," ",
 #ifdef DEBUG
 		  "-U"," ",pass," ",
@@ -401,12 +406,13 @@ SMBList (GtkTreeView *treeview,char *path,GtkTreeIter *iter,
 		  "-c", " ",NMBcommand,"\n",
 		  NULL);
 
+  reset_dummy_row(treemodel,iter,NULL,NULL,"xfce/warning",_("Loading..."));
   smb_object = Tubo (fork_function,
 	(void *)argument, 
 	SMBListForkOver, 
-	TRUE, 
+	NULL, 
 	SMBListStdout, 
-	smb_stderr);
+	smb_stderr,0,FALSE);
   
   smb_wait(TRUE);
 
@@ -416,4 +422,5 @@ SMBList (GtkTreeView *treeview,char *path,GtkTreeIter *iter,
   return query_result;
 }
 
+#endif
 
