@@ -1,6 +1,8 @@
 void init_xffm_env(void);
-void xffm_setenv(GtkTreeView *treeview,const char *name,
+void xffm_setenv(const char *name,
 		char *value,gboolean verbose);
 
 void set_active_mcs(gboolean state);
 void connect_mcs(void);
+void
+mcs_stop_watch (void);
